==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/firstrunwizard/l10n/de.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Willkommen bei %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Deine persönlichen Web-Dienste. Alle Deine Dateien, Kontakte, Kalender und mehr an einem Ort.",
"Get the apps to sync your files" => "Lade die Apps zur Synchronisierung Deiner Daten herunter",
"Desktop client" => "Desktop-Client",
"Android app" => "Android-App",
"iOS app" => "iOS-App",
"Connect your desktop apps to %s" => "Verbinde Deine Desktop-Anwendungen mit %s",
"Connect your Calendar" => "Verbinde Deine Kalender ",
"Connect your Contacts" => "Verbinde Deine Kontakte",
"Access files via WebDAV" => "Greife auf Dateien über WebDAV zu",
"Documentation" => "Dokumentation",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Weitere Informationen findest Du in der <a target=\"_blank\" href=\"%s\">Dokumentation</a> und auf unserer <a target=\"_blank\" href=\"http://owncloud.org\">Webseite</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Wenn Dir ownCloud gefällt,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud ist eine großartige freie Software zum Synchronisieren und Freigeben Deiner Dateien.\n\t\tDu kannst es kostenlos von http://owncloud.org beziehen\">\n\t\tempfehle es Deinem Freundeskreis</a>\n\tund <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">sorge dafür, dass es bekannter wird</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/firstrunwizard/l10n/de.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Willkommen bei %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Deine persönlichen Web-Dienste. Alle Deine Dateien, Kontakte, Kalender und mehr an einem Ort.",
"Get the apps to sync your files" => "Lade die Apps zur Synchronisierung Deiner Daten herunter",
"Desktop client" => "Desktop-Client",
"Android app" => "Android-App",
"iOS app" => "iOS-App",
"Connect your desktop apps to %s" => "Verbinde Deine Desktop-Anwendungen mit %s",
"Connect your Calendar" => "Verbinde Deine Kalender ",
"Connect your Contacts" => "Verbinde Deine Kontakte",
"Access files via WebDAV" => "Greife auf Dateien über WebDAV zu",
"Documentation" => "Dokumentation",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Weitere Informationen findest Du in der <a target=\"_blank\" href=\"%s\">Dokumentation</a> und auf unserer <a target=\"_blank\" href=\"http://owncloud.org\">Webseite</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Wenn Dir ownCloud gefällt, <a href=\"mailto:?subject=ownCloud\t&body=ownCloud ist eine großartige freie Software zum Synchronisieren und Freigeben Deiner Dateien. \nDu kannst es kostenlos von http://owncloud.org beziehen\">empfehle es Deinem Freundeskreis</a> und <a href=\"http://owncloud.org/promote\" target=\"_blank\">sorge dafür, dass es bekannter wird</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
